This repository contains utility functions that aim to help Atri users in writing backend easily.

## How to contribute?

1. Request a new utility funciton in `Issues`.
2. Discuss any problems with existing utility functions in `Issues`.
3. Add or improve existing functions available at src/atri_utils. 
4. Add a new Python file at src/atri_utils. Make sure you add the import statements at `_init_.py`.